@@ -488,8 +488,7 @@ main(int argc, char **argv)
 "                            on Microsoft DFS shares.\n"
 "  -C, --track-ctime         track each file's ctime so we can detect changes\n"
 "                            to ownership or permissions.\n"
-"      --date-terms          ignored for forward compatibility with Omega\n"
-"                            1.5.x.\n"
+"      --date-terms          ignored for forward compatibility with Omega 2.\n"
 "      --no-date-terms       don't index D, M and Y prefixed terms to support\n"
 "                            date range filtering using terms (we now recommend\n"
 "                            using a value slot for this instead).\n"
@@ -678,7 +677,7 @@ main(int argc, char **argv)
 	    use_ctime = true;
 	    break;
 	case OPT_DATE_TERMS:
-	    // Ignored for compatibility with Omega 1.5.0.
+	    // Ignored for compatibility with Omega 2.0.0.
 	    break;
 	case OPT_NO_DATE_TERMS:
 	    date_terms = false;
